@@ -45,14 +45,14 @@ class ResponseTestCase(PandaggTestCase):
                         "_type": "_doc",
                         "_id": "1",
                         "_score": 1.0,
-                        "_source": {"field_23": 1},
+                        "_source": {"field_23": 1, "yo": 2},
                     },
                     {
                         "_index": "my_index_01",
                         "_type": "_doc",
                         "_id": "2",
                         "_score": 0.2,
-                        "_source": {"field_23": 2},
+                        "_source": {"field_23": 2, "to": 1},
                     },
                 ],
             }
@@ -65,6 +65,31 @@ class ResponseTestCase(PandaggTestCase):
             self.assertIsInstance(h, Hit)
         self.assertEqual(hits.__repr__(), "<Hits> total: 34, contains 2 hits")
 
+        # as dataframe
+        source_only_df = hits.to_dataframe()
+        with_metadata_df = hits.to_dataframe(source_only=False)
+        non_expanded_df = hits.to_dataframe(expand_source=False)
+
+        self.assertEqual(
+            sorted(source_only_df.columns.tolist()), sorted(["field_23", "to", "yo"])
+        )
+        self.assertEqual(source_only_df.shape, (2, 3))
+        self.assertEqual(source_only_df.index.tolist(), ["1", "2"])
+
+        self.assertEqual(
+            sorted(with_metadata_df.columns.tolist()),
+            sorted(["_index", "_score", "_type", "field_23", "to", "yo"]),
+        )
+        self.assertEqual(with_metadata_df.shape, (2, 6))
+        self.assertEqual(with_metadata_df.index.tolist(), ["1", "2"])
+
+        self.assertEqual(
+            sorted(non_expanded_df.columns.tolist()),
+            ["_index", "_score", "_source", "_type"],
+        )
+        self.assertEqual(non_expanded_df.shape, (2, 4))
+        self.assertEqual(non_expanded_df.index.tolist(), ["1", "2"])
+
     def test_response(self):
         r = Response(
             {
